#!/bin/bash
# For each version of FNPLicensingService bundled with this utility, remove the matching version on this machine.

# Set working directory to script directory.
cd "$(dirname ${BASH_SOURCE[0]})"

# Iterate through each directory bundled with this utility. 
for REMOVE_FNP_DIR in $(find ./ -type d -mindepth 1 -maxdepth 1 | sort -V)
do 
    # Check if directory contains an install_fnp.sh script. 
    if [[ -x "$REMOVE_FNP_DIR/install_fnp.sh" ]]
    then 
        REMOVE_FNP_VER=$(basename $REMOVE_FNP_DIR)
        # Versions in the utility are labeled in the v#.# format, whereas those installed are labeled in the #.#.# format.
        # So we have to process the string first.
        # Break the version string into major, minor and patch number, excluding the v and excluding any extra number.
        # This handles cases where the version is a single number or two numbers separated by a period or more.
        if [[ $REMOVE_FNP_VER =~ ^v([[:digit:]]+)\.?([[:digit:]]+)?\.?([[:digit:]]+)?.*$ ]]
        then 
            MAJOR_VER=${BASH_REMATCH[1]}
            [[ -n ${BASH_REMATCH[2]} ]] && MINOR_VER=${BASH_REMATCH[2]} || MINOR_VER=0
            [[ -n ${BASH_REMATCH[3]} ]] && PATCH_VER=${BASH_REMATCH[3]} || PATCH_VER=0            
            REMOVE_FNP_VER_CLEAN="${MAJOR_VER}.${MINOR_VER}.${PATCH_VER}"
            
            if [[ -d "/Library/Application Support/FLEXnet Publisher/Service/${REMOVE_FNP_VER_CLEAN}" ]]
            then             
                echo "Removing old anchor service version $REMOVE_FNP_VER..." > $STDOUT
                rm -frv "/Library/Application Support/FLEXnet Publisher/Service/${REMOVE_FNP_VER_CLEAN}" > $STDOUT
                [[ $? == 0 ]] && echo "Removed anchor service version $REMOVE_FNP_VER." > $APPOUT
            fi
        fi
    fi 
done 